<!-- Do not edit this file. It is automatically generated by API Documenter. -->

[Home](./index.md) &gt; [kibana-plugin-core-server](./kibana-plugin-core-server.md) &gt; [CapabilitiesSetup](./kibana-plugin-core-server.capabilitiessetup.md) &gt; [registerSwitcher](./kibana-plugin-core-server.capabilitiessetup.registerswitcher.md)

## CapabilitiesSetup.registerSwitcher() method

Register a [CapabilitiesSwitcher](./kibana-plugin-core-server.capabilitiesswitcher.md) to be used to change the default state of the [Capabilities](./kibana-plugin-core-server.capabilities.md) entries when resolving them.

A capabilities switcher can only change the state of existing capabilities. Capabilities added or removed when invoking the switcher will be ignored.

**Signature:**

```typescript
registerSwitcher(switcher: CapabilitiesSwitcher): void;
```

## Parameters

|  Parameter | Type | Description |
|  --- | --- | --- |
|  switcher | CapabilitiesSwitcher |  |

**Returns:**

void

## Example

How to restrict some capabilities

```ts
// my-plugin/server/plugin.ts
public setup(core: CoreSetup, deps: {}) {
   core.capabilities.registerSwitcher((request, capabilities, useDefaultCapabilities) => {
     // useDefaultCapabilities is a special case that switchers typically don't have to concern themselves with.
     // The default capabilities are typically the ones you provide in your CapabilitiesProvider, but this flag
     // gives each switcher an opportunity to change the default capabilities of other plugins' capabilities.
     // For example, you may decide to flip another plugin's capability to false if today is Tuesday,
     // but you wouldn't want to do this when we are requesting the default set of capabilities.
     if (useDefaultCapabilities) {
       return {
         somePlugin: {
           featureEnabledByDefault: true
         }
       }
     }
     if(myPluginApi.shouldRestrictSomePluginBecauseOf(request)) {
       return {
         somePlugin: {
           featureEnabledByDefault: false // `featureEnabledByDefault` will be disabled. All other capabilities will remain unchanged.
         }
       }
     }
     return {}; // All capabilities will remain unchanged.
   });
}
```

