<!-- Do not edit this file. It is automatically generated by API Documenter. -->

[Home](./index.md) &gt; [kibana-plugin-core-server](./kibana-plugin-core-server.md) &gt; [HttpServicePreboot](./kibana-plugin-core-server.httpservicepreboot.md)

## HttpServicePreboot interface

Kibana HTTP Service provides an abstraction to work with the HTTP stack at the `preboot` stage. This functionality allows Kibana to serve user requests even before Kibana becomes fully operational. Only Core and `preboot` plugins can define HTTP routes at this stage.

**Signature:**

```typescript
export interface HttpServicePreboot 
```

## Example

To handle an incoming request in your preboot plugin you should: - Use `@kbn/config-schema` package to create a schema to validate the request `params`<!-- -->, `query`<!-- -->, and `body`<!-- -->. Every incoming request will be validated against the created schema. If validation failed, the request is rejected with `400` status and `Bad request` error without calling the route's handler. To opt out of validating the request, specify `false`<!-- -->.

```ts
import { schema, TypeOf } from '@kbn/config-schema';
const validate = {
  params: schema.object({
    id: schema.string(),
  }),
};
```
- Declare a function to respond to incoming request. The function will receive `request` object containing request details: url, headers, matched route, as well as validated `params`<!-- -->, `query`<!-- -->, `body`<!-- -->. And `response` object instructing HTTP server to create HTTP response with information sent back to the client as the response body, headers, and HTTP status. Any exception raised during the handler call will generate `500 Server error` response and log error details for further investigation. See below for returning custom error responses.

```ts
const handler = async (context: RequestHandlerContext, request: KibanaRequest, response: ResponseFactory) => {
  const data = await findObject(request.params.id);
  // creates a command to respond with 'not found' error
  if (!data) {
    return response.notFound();
  }
  // creates a command to send found data to the client and set response headers
  return response.ok({
    body: data,
    headers: { 'content-type': 'application/json' }
  });
}
```
\* - Acquire `preboot` [IRouter](./kibana-plugin-core-server.irouter.md) instance and register route handler for GET request to 'path/<!-- -->{<!-- -->id<!-- -->}<!-- -->' path.

```ts
import { schema, TypeOf } from '@kbn/config-schema';

const validate = {
  params: schema.object({
    id: schema.string(),
  }),
};

httpPreboot.registerRoutes('my-plugin', (router) => {
  router.get({ path: 'path/{id}', validate }, async (context, request, response) => {
    const data = await findObject(request.params.id);
    if (!data) {
      return response.notFound();
    }
    return response.ok({
      body: data,
      headers: { 'content-type': 'application/json' }
    });
  });
});
```

## Properties

|  Property | Modifiers | Type | Description |
|  --- | --- | --- | --- |
|  [basePath](./kibana-plugin-core-server.httpservicepreboot.basepath.md) |  | IBasePath | Access or manipulate the Kibana base path See [IBasePath](./kibana-plugin-core-server.ibasepath.md)<!-- -->. |
|  [getServerInfo](./kibana-plugin-core-server.httpservicepreboot.getserverinfo.md) |  | () =&gt; HttpServerInfo | Provides common [information](./kibana-plugin-core-server.httpserverinfo.md) about the running preboot http server. |

## Methods

|  Method | Description |
|  --- | --- |
|  [registerRoutes(path, callback)](./kibana-plugin-core-server.httpservicepreboot.registerroutes.md) | Provides ability to acquire <code>preboot</code> [IRouter](./kibana-plugin-core-server.irouter.md) instance for a particular top-level path and register handler functions for any number of nested routes. |

