<!-- Do not edit this file. It is automatically generated by API Documenter. -->

[Home](./index.md) &gt; [kibana-plugin-core-server](./kibana-plugin-core-server.md) &gt; [SavedObjectsExportTransform](./kibana-plugin-core-server.savedobjectsexporttransform.md)

## SavedObjectsExportTransform type

Transformation function used to mutate the exported objects of the associated type.

A type's export transform function will be executed once per user-initiated export, for all objects of that type.

**Signature:**

```typescript
export declare type SavedObjectsExportTransform<T = unknown> = (context: SavedObjectsExportTransformContext, objects: Array<SavedObject<T>>) => SavedObject[] | Promise<SavedObject[]>;
```

## Remarks

Trying to change an object's id or type during the transform will result in a runtime error during the export process.

## Example 1

Registering a transform function changing the object's attributes during the export

```ts
// src/plugins/my_plugin/server/plugin.ts
import { myType } from './saved_objects';

export class Plugin() {
  setup: (core: CoreSetup) => {
    core.savedObjects.registerType({
       ...myType,
       management: {
         ...myType.management,
         onExport: (ctx, objects) => {
           return objects.map((obj) => ({
             ...obj,
             attributes: {
               ...obj.attributes,
               enabled: false,
             }
           })
         }
       },
    });
  }
}
```

## Example 2

Registering a transform function adding additional objects to the export

```ts
// src/plugins/my_plugin/server/plugin.ts
import { myType } from './saved_objects';

export class Plugin() {
  setup: (core: CoreSetup) => {
    const savedObjectStartContractPromise = getStartServices().then(
      ([{ savedObjects: savedObjectsStart }]) => savedObjectsStart
    );

    core.savedObjects.registerType({
       ...myType,
       management: {
         ...myType.management,
         onExport: async (ctx, objects) => {
           const { getScopedClient } = await savedObjectStartContractPromise;
           const client = getScopedClient(ctx.request);

           const depResponse = await client.find({
             type: 'my-nested-object',
             hasReference: objs.map(({ id, type }) => ({ id, type })),
           });

           return [...objs, ...depResponse.saved_objects];
         }
       },
    });
  }
}
```

