<!-- Do not edit this file. It is automatically generated by API Documenter. -->

[Home](./index.md) &gt; [kibana-plugin-core-server](./kibana-plugin-core-server.md) &gt; [SavedObjectsRepository](./kibana-plugin-core-server.savedobjectsrepository.md) &gt; [closePointInTime](./kibana-plugin-core-server.savedobjectsrepository.closepointintime.md)

## SavedObjectsRepository.closePointInTime() method

Closes a Point In Time (PIT) by ID. This simply proxies the request to ES via the Elasticsearch client, and is included in the Saved Objects Client as a convenience for consumers who are using `openPointInTimeForType`<!-- -->.

Only use this API if you have an advanced use case that's not solved by the [SavedObjectsRepository.createPointInTimeFinder()](./kibana-plugin-core-server.savedobjectsrepository.createpointintimefinder.md) method.

**Signature:**

```typescript
closePointInTime(id: string, options?: SavedObjectsClosePointInTimeOptions): Promise<SavedObjectsClosePointInTimeResponse>;
```

## Parameters

|  Parameter | Type | Description |
|  --- | --- | --- |
|  id | string |  |
|  options | SavedObjectsClosePointInTimeOptions | _(Optional)_ [SavedObjectsClosePointInTimeOptions](./kibana-plugin-core-server.savedobjectsclosepointintimeoptions.md) |

**Returns:**

Promise&lt;SavedObjectsClosePointInTimeResponse&gt;

{<!-- -->promise<!-- -->} - [SavedObjectsClosePointInTimeResponse](./kibana-plugin-core-server.savedobjectsclosepointintimeresponse.md)

## Remarks

While the `keepAlive` that is provided will cause a PIT to automatically close, it is highly recommended to explicitly close a PIT when you are done with it in order to avoid consuming unneeded resources in Elasticsearch.

## Example


```ts
const repository = coreStart.savedObjects.createInternalRepository();

const { id } = await repository.openPointInTimeForType(
  type: 'index-pattern',
  { keepAlive: '2m' },
);

const response = await repository.find({
  type: 'index-pattern',
  search: 'foo*',
  sortField: 'name',
  sortOrder: 'desc',
  pit: {
    id: 'abc123',
    keepAlive: '2m',
  },
  searchAfter: [1234, 'abcd'],
});

await repository.closePointInTime(response.pit_id);
```

