<!-- Do not edit this file. It is automatically generated by API Documenter. -->

[Home](./index.md) &gt; [kibana-plugin-core-server](./kibana-plugin-core-server.md) &gt; [SavedObjectsRepository](./kibana-plugin-core-server.savedobjectsrepository.md) &gt; [incrementCounter](./kibana-plugin-core-server.savedobjectsrepository.incrementcounter.md)

## SavedObjectsRepository.incrementCounter() method

Increments all the specified counter fields (by one by default). Creates the document if one doesn't exist for the given id.

**Signature:**

```typescript
incrementCounter<T = unknown>(type: string, id: string, counterFields: Array<string | SavedObjectsIncrementCounterField>, options?: SavedObjectsIncrementCounterOptions<T>): Promise<SavedObject<T>>;
```

## Parameters

|  Parameter | Type | Description |
|  --- | --- | --- |
|  type | string | The type of saved object whose fields should be incremented |
|  id | string | The id of the document whose fields should be incremented |
|  counterFields | Array&lt;string \| SavedObjectsIncrementCounterField&gt; | An array of field names to increment or an array of [SavedObjectsIncrementCounterField](./kibana-plugin-core-server.savedobjectsincrementcounterfield.md) |
|  options | SavedObjectsIncrementCounterOptions&lt;T&gt; | _(Optional)_ [SavedObjectsIncrementCounterOptions](./kibana-plugin-core-server.savedobjectsincrementcounteroptions.md) |

**Returns:**

Promise&lt;SavedObject&lt;T&gt;&gt;

The saved object after the specified fields were incremented

## Remarks

When supplying a field name like `stats.api.counter` the field name will be used as-is to create a document like: `{attributes: {'stats.api.counter': 1}}` It will not create a nested structure like: `{attributes: {stats: {api: {counter: 1}}}}`

When using incrementCounter for collecting usage data, you need to ensure that usage collection happens on a best-effort basis and doesn't negatively affect your plugin or users. See https://github.com/elastic/kibana/blob/main/src/plugins/usage\_collection/README.mdx\#tracking-interactions-with-incrementcounter)

## Example


```ts
const repository = coreStart.savedObjects.createInternalRepository();

// Initialize all fields to 0
repository
  .incrementCounter('dashboard_counter_type', 'counter_id', [
    'stats.apiCalls',
    'stats.sampleDataInstalled',
  ], {initialize: true});

// Increment the apiCalls field counter
repository
  .incrementCounter('dashboard_counter_type', 'counter_id', [
    'stats.apiCalls',
  ])

// Increment the apiCalls field counter by 4
repository
  .incrementCounter('dashboard_counter_type', 'counter_id', [
    { fieldName: 'stats.apiCalls' incrementBy: 4 },
  ])

// Initialize the document with arbitrary fields if not present
repository.incrementCounter<{ appId: string }>(
  'dashboard_counter_type',
  'counter_id',
  [ 'stats.apiCalls'],
  { upsertAttributes: { appId: 'myId' } }
)
```

