<!-- Do not edit this file. It is automatically generated by API Documenter. -->

[Home](./index.md) &gt; [kibana-plugin-core-server](./kibana-plugin-core-server.md) &gt; [SavedObjectsTypeManagementDefinition](./kibana-plugin-core-server.savedobjectstypemanagementdefinition.md) &gt; [isExportable](./kibana-plugin-core-server.savedobjectstypemanagementdefinition.isexportable.md)

## SavedObjectsTypeManagementDefinition.isExportable property

Optional hook to specify whether an object should be exportable.

If specified, `isExportable` will be called during export for each of this type's objects in the export, and the ones not matching the predicate will be excluded from the export.

When implementing both `isExportable` and `onExport`<!-- -->, it is mandatory that `isExportable` returns the same value for an object before and after going though the export transform. E.g `isExportable(objectBeforeTransform) === isExportable(objectAfterTransform)`

**Signature:**

```typescript
isExportable?: SavedObjectsExportablePredicate<Attributes>;
```

## Remarks

`importableAndExportable` must be `true` to specify this property.

## Example

Registering a type with a per-object exportability predicate

```ts
// src/plugins/my_plugin/server/plugin.ts
import { myType } from './saved_objects';

export class Plugin() {
  setup: (core: CoreSetup) => {
    core.savedObjects.registerType({
       ...myType,
       management: {
         ...myType.management,
         isExportable: (object) => {
           if (object.attributes.myCustomAttr === 'foo') {
             return false;
           }
           return true;
         }
       },
    });
  }
}
```

